@@ -70,6 +70,7 @@ JsonSchemaType = Literal["string", "number", "boolean", "object", "array", "butt
 LoggerLevel = Literal["error", "warn", "info", "debug", "trace", "attention", "success"]
 APIEventType = Literal["finishLaunching", "shutdown"]
 PTZMovementType = Literal["absolute", "relative", "continuous", "home", "preset", "stop"]
+RTSPAudioCodec = Literal["aac", "opus", "pcma"]
 
 # Basic types
 Callback = Union[
@@ -530,7 +531,7 @@ class CameraDelegates(TypedDict):
 
 class RTSPUrlOptions(TypedDict, total=False):
     video: bool
-    audio: Union[bool, str, list[str]]
+    audio: Union[bool, RTSPAudioCodec, list[RTSPAudioCodec]]
     audioSingleTrack: bool
     backchannel: bool
     timeout: int
@@ -555,9 +556,9 @@ class CameraSource(Protocol):
 
 class CameraDeviceSource(CameraSource, Protocol):
     def generate_rtsp_url(self, options: RTSPUrlOptions) -> str: ...
-    def create_webrtc_session(self) -> None: ...
-    def create_rtsp_session(self) -> None: ...
-    def create_fmp4_session(self) -> None: ...
+    def create_webrtc_session(self, options: "WebRTCConnectionOptions") -> None: ...
+    def create_rtsp_session(self, options: "RTSPConnectionOptions") -> None: ...
+    def create_fmp4_session(self, options: "FMP4ConnectionOptions") -> None: ...
 
 
 class WebRTCConnectionOptions(TypedDict, total=False):
@@ -565,21 +566,11 @@ class WebRTCConnectionOptions(TypedDict, total=False):
 
 
 class RTSPConnectionOptions(TypedDict, total=False):
-    target: Literal[
-        "default",
-        "aac",
-        "opus",
-        "pcma",
-    ]
+    url: str
 
 
 class FMP4ConnectionOptions(TypedDict, total=False):
-    target: Literal[
-        "default",
-        "aac",
-        "opus",
-        "pcma",
-    ]
+    url: str
 
 
 SpawnInput = Union[str, int]
